# RentcastRentalListingsLongTerm200ResponseInnerListingAgent


## Properties

Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**name** | **str** |  | [optional] 
**phone** | **str** |  | [optional] 
**email** | **str** |  | [optional] 
**website** | **str** |  | [optional] 

## Example

```python
from rentcast_client.models.rentcast_rental_listings_long_term200_response_inner_listing_agent import RentcastRentalListingsLongTerm200ResponseInnerListingAgent

# TODO update the JSON string below
json = "{}"
# create an instance of RentcastRentalListingsLongTerm200ResponseInnerListingAgent from a JSON string
rentcast_rental_listings_long_term200_response_inner_listing_agent_instance = RentcastRentalListingsLongTerm200ResponseInnerListingAgent.from_json(json)
# print the JSON string representation of the object
print(RentcastRentalListingsLongTerm200ResponseInnerListingAgent.to_json())

# convert the object into a dict
rentcast_rental_listings_long_term200_response_inner_listing_agent_dict = rentcast_rental_listings_long_term200_response_inner_listing_agent_instance.to_dict()
# create an instance of RentcastRentalListingsLongTerm200ResponseInnerListingAgent from a dict
rentcast_rental_listings_long_term200_response_inner_listing_agent_from_dict = RentcastRentalListingsLongTerm200ResponseInnerListingAgent.from_dict(rentcast_rental_listings_long_term200_response_inner_listing_agent_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


